==> react-poppop-1.0.0.tgz: package/docs/root.js <==
import React from 'react';
import ReactDOM from 'react-dom';
import AllPosition from './components/AllPosition';
import LongContent from './components/LongContent';
import ShortContent from './components/ShortContent';

export default class Root extends React.Component {
  render() {
    return (
      <div className="code">
        <div className="mw8 center mb4" style={{textAlign: 'center'}}>
          <h1 className="f1">React PopPop</h1>
          <p className="f3">
            A responsive, mobile support and multi directions modal for ReactJS.
          </p>
          <a className="github-button" href="https://github.com/ctxhou/react-poppop" data-size="large" data-show-count="true" aria-label="Star ctxhou/react-poppop on GitHub">Star</a>
          <div>
            <a className="f6 link dim br-pill ba bw1 ph3 pv2 mt3 mb1 dib green"
               href="https://github.com/ctxhou/react-poppop"
               target="_blank">
              Document
            </a>            
          </div>
          <hr className="ma4"/>
          <div className="ph3-ns">
            <div className="cf ph2-ns">
              <div className="fl w-100 w-third-ns pa2">
                <AllPosition/>
              </div>
              <div className="fl w-100 w-third-ns pa2">
                <LongContent/>
              </div>
              <div className="fl w-100 w-third-ns pa2">
                <ShortContent/>
              </div>
            </div>
          </div>
        </div>
        <footer className="pv4 ph3 ph5-m ph6-l mid-gray mt6-m">
          <small className="f6 db tc">Maintained by <a href="https://github.com/ctxhou">@ctxhou</a></small>
          <div className="tc mt3">
            <a className="link dim gray dib br-100 h2 w2 mr3 " href="https://github.com/ctxhou/react-poppop" title="">
              <svg data-icon="github" viewBox="0 0 32 32" style={{fill: 'currentcolor'}}>
                <title>github icon</title>
                <path d="M0 18 C0 12 3 10 3 9 C2.5 7 2.5 4 3 3 C6 3 9 5 10 6 C12 5 14 5 16 5 C18 5 20 5 22 6 C23 5 26 3 29 3 C29.5 4 29.5 7 29 9 C29 10 32 12 32 18 C32 25 30 30 16 30 C2 30 0 25 0 18 M3 20 C3 24 4 28 16 28 C28 28 29 24 29 20 C29 16 28 14 16 14 C4 14 3 16 3 20 M8 21 A1.5 2.5 0 0 0 13 21 A1.5 2.5 0 0 0 8 21 M24 21 A1.5 2.5 0 0 0 19 21 A1.5 2.5 0 0 0 24 21 z"></path>
              </svg>
            </a>
          </div>
        </footer>
      </div>
    )
  }
}

ReactDOM.render(
  <Root/>,
  document.getElementById('root')
);

if (module.hot) {
  module.hot.accept();
}

==> react-poppop-1.5.0.tgz: package/docs/root.js <==
import React from 'react';
import ReactDOM from 'react-dom';
import AllPosition from './components/AllPosition';
import LongContent from './components/LongContent';
import ShortContent from './components/ShortContent';

export default class Root extends React.Component {
  render() {
    return (
      <div className="code">
        <div className="mw8 center mb4" style={{textAlign: 'center'}}>
          <h1 className="f1">React PopPop</h1>
          <p className="f3">
            A responsive, mobile support and multi directions modal for ReactJS.
          </p>
          <a className="github-button" href="https://github.com/ctxhou/react-poppop" data-size="large" data-show-count="true" aria-label="Star ctxhou/react-poppop on GitHub">Star</a>
          <div>
            <a className="f6 link dim br-pill ba bw1 ph3 pv2 mt3 mb1 dib green"
               href="https://github.com/ctxhou/react-poppop"
               target="_blank">
              Document
            </a>            
          </div>
          <hr className="ma4"/>
          <div className="ph3-ns">
            <div className="cf ph2-ns">
              <div className="fl w-100 w-third-ns pa2">
                <AllPosition/>
                <div className="mt2">
                  <a href="https://github.com/ctxhou/react-poppop/blob/master/docs/components/allPosition.js" className="green">Source code</a>                  
                </div>
              </div>
              <div className="fl w-100 w-third-ns pa2">
                <LongContent/>
                <div className="mt2">
                  <a href="https://github.com/ctxhou/react-poppop/blob/master/docs/components/LongContent.js" className="green">Source code</a>                  
                </div>
              </div>
              <div className="fl w-100 w-third-ns pa2">
                <ShortContent/>
                <div className="mt2">
                  <a href="https://github.com/ctxhou/react-poppop/blob/master/docs/components/ShortContent.js" className="green">Source code</a>                  
                </div>
              </div>
            </div>
          </div>
        </div>
        <footer className="pv4 ph3 ph5-m ph6-l mid-gray mt6-m mt6-l">
          <small className="f6 db tc">Maintained by <a href="https://github.com/ctxhou">@ctxhou</a></small>
          <div className="tc mt3">
            <a className="link dim gray dib br-100 h2 w2 mr3 " href="https://github.com/ctxhou/react-poppop" title="">
              <svg data-icon="github" viewBox="0 0 32 32" style={{fill: 'currentcolor'}}>
                <title>github icon</title>
                <path d="M0 18 C0 12 3 10 3 9 C2.5 7 2.5 4 3 3 C6 3 9 5 10 6 C12 5 14 5 16 5 C18 5 20 5 22 6 C23 5 26 3 29 3 C29.5 4 29.5 7 29 9 C29 10 32 12 32 18 C32 25 30 30 16 30 C2 30 0 25 0 18 M3 20 C3 24 4 28 16 28 C28 28 29 24 29 20 C29 16 28 14 16 14 C4 14 3 16 3 20 M8 21 A1.5 2.5 0 0 0 13 21 A1.5 2.5 0 0 0 8 21 M24 21 A1.5 2.5 0 0 0 19 21 A1.5 2.5 0 0 0 24 21 z"></path>
              </svg>
            </a>
          </div>
        </footer>
      </div>
    )
  }
}

ReactDOM.render(
  <Root/>,
  document.getElementById('root')
);

if (module.hot) {
  module.hot.accept();
}
